@@ -1,6 +1,6 @@
 package Outthentic;
 
-our $VERSION = '0.2.14';
+our $VERSION = '0.2.15';
 
 1;
 
@@ -54,6 +54,11 @@ sub config {
   $config
 }
 
+sub dump_config {
+  my $json = JSON->new->pretty;
+  print $json->encode(config());
+}
+
 sub nocolor {
   get_prop('nocolor')
 }
@@ -63,7 +68,11 @@ sub populate_config {
     unless ($config){
         if (get_prop('ini_file_path') and -f get_prop('ini_file_path') ){
           my $path = get_prop('ini_file_path');
-          my %config  = Config::General->new( -InterPolateVars => 1 , -ConfigFile => $path )->getall or confess "file $path is not valid config file";
+          my %config  = Config::General->new( 
+            -InterPolateVars => 1 ,
+            -InterPolateEnv  => 1 ,
+            -ConfigFile => $path 
+          )->getall or confess "file $path is not valid config file";
           $config = {%config};
         }elsif(get_prop('yaml_file_path') and -f get_prop('yaml_file_path')){
           my $path = get_prop('yaml_file_path');
@@ -76,7 +85,11 @@ sub populate_config {
           $config = from_json($json_str);
         }elsif ( -f 'suite.ini' ){
           my $path = 'suite.ini';
-          my %config = Config::General->new( -InterPolateVars => 1 , -ConfigFile => $path )->getall or confess "file $path is not valid config file";
+          my %config  = Config::General->new( 
+            -InterPolateVars => 1 ,
+            -InterPolateEnv  => 1 ,
+            -ConfigFile => $path 
+          )->getall or confess "file $path is not valid config file";
           $config = {%config};
         }elsif ( -f 'suite.yaml'){
           my $path = 'suite.yaml';
@@ -96,7 +109,11 @@ sub populate_config {
 
     if ( -f 'suite.ini' ){
       my $path = 'suite.ini';
-      my %config = Config::General->new( -InterPolateVars => 1 , -ConfigFile => $path )->getall or confess "file $path is not valid config file";
+      my %config  = Config::General->new( 
+        -InterPolateVars => 1 ,
+        -InterPolateEnv  => 1 ,
+        -ConfigFile => $path 
+      )->getall or confess "file $path is not valid config file";
       $default_config = {%config};
     }
 
@@ -1443,7 +1460,18 @@ C<--nocolor>
 
 =back
 
-If set disable color output. By default C<strun> prints with colors.
+If set - disable color output. By default C<strun> prints with colors.
+
+=over
+
+=item *
+
+C<--dump-config>
+
+
+=back
+
+If set - dumps a suite configuration and exit not doing any other actions. See also suite configuration section.
 
 
 =head1 Suite configuration
